@@ -1437,7 +1437,7 @@ def _recursive_concatenate_SparseNdarray(contents: list, final_shape: Tuple[int,
             _coerce_concatenated_SparseNdarray_types(new_contents, payload=payload, dim=dim)
         return new_contents
 
-    elif dim == len(final_shape) - 2:
+    elif dim == 1:
         new_contents = []
         for i in range(final_shape[dim]):
             outidx = []
@@ -1463,7 +1463,7 @@ def _recursive_concatenate_SparseNdarray(contents: list, final_shape: Tuple[int,
         return new_contents
 
 
-def _concatenate_SparseNdarray(xs: list[SparseNdarray], along: int):
+def _concatenate_SparseNdarray(xs: List[SparseNdarray], along: int):
     all_contents = []
     all_shapes = []
     for x in xs:
