@@ -33,5 +33,6 @@ from .create_dask_array import create_dask_array
 from .is_sparse import is_sparse
 from .chunk_shape import chunk_shape
 from .is_pristine import is_pristine
-from .guess_iteration_block_size import guess_iteration_block_size
+from .apply_over_dimension import apply_over_dimension, choose_block_size_for_1d_iteration, guess_iteration_block_size
+from .apply_over_blocks import apply_over_blocks, choose_block_shape_for_iteration
 from .wrap import wrap
